@@ -81,48 +81,13 @@ def revival_svdata_flag(new_obj, old_obj) -> None:
         util.new_flag_svdict(entry, "game_data.sav")
 
 
-def isget_bgdata_flag(actor_name: str) -> int:
-    flag_name: str = f"IsGet_{actor_name}"
-    flag_hash: int = ctypes.c_int32(zlib.crc32(flag_name.encode())).value
-
-    entry = oead.byml.Hash()
-    entry["DataName"] = flag_name
-    entry["DeleteRev"] = oead.S32(-1)
-    entry["HashValue"] = oead.S32(flag_hash)
-    entry["InitValue"] = oead.S32(0)
-    entry["IsEventAssociated"] = False
-    entry["IsOneTrigger"] = True
-    entry["IsProgramReadable"] = True
-    entry["IsProgramWritable"] = True
-    entry["IsSave"] = True
-    entry["MaxValue"] = True
-    entry["MinValue"] = False
-    entry["ResetType"] = oead.S32(0)
-
-    util.new_flag_bgdict(entry, "bool_data")
-
-    return flag_hash
-
-
-def isget_svdata_flag(actor_name: str) -> int:
-    flag_name: str = f"IsGet_{actor_name}"
-    flag_hash: int = ctypes.c_int32(zlib.crc32(flag_name.encode())).value
-
-    entry = oead.byml.Hash()
-    entry["DataName"] = flag_name
-    entry["HashValue"] = oead.S32(flag_hash)
-
-    util.new_flag_svdict(entry, "game_data.sav")
-
-    return flag_hash
-
-
 def generate_revival_flags(moddir: Path) -> None:
     util.prep_entry_dicts_for_run("revival_bool_data")
 
     for map_unit in moddir.rglob("**/*_*.smubin"):
         map_start = time.time()
         map_data = oead.byml.from_binary(bcmlutil.decompress(map_unit.read_bytes()))
+        map_hashes = [obj["HashId"].v for obj in map_data["Objs"]]
         map_section = map_unit.stem.split("_")
         stock_map = mubin.get_stock_map((map_section[0], map_section[1]))
         stock_hashes = [obj["HashId"].v for obj in stock_map["Objs"]]
@@ -142,9 +107,64 @@ def generate_revival_flags(moddir: Path) -> None:
                     revival_bgdata_flag(obj, stock_obj)
                     if name_changed:
                         revival_svdata_flag(obj, stock_obj)
+        for obj in stock_map["Objs"]:
+            if obj["HashId"].v not in map_hashes:
+                old_hash: int = ctypes.c_int32(
+                    zlib.crc32(f"MainField_{obj['UnitConfigName']}_{obj['HashId'].v}".encode())
+                ).value
+                util.rem_flag_bgdict(old_hash, "revival_bool_data")
+                util.rem_flag_svdict(old_hash, "game_data.sav")
         print(f"Finished processing {map_unit.name} in {time.time() - map_start} seconds...")
 
 
+def isget_bgdata_flag(actor_name: str) -> int:
+    flag_name: str = f"IsGet_{actor_name}"
+    flag_hash: int = ctypes.c_int32(zlib.crc32(flag_name.encode())).value
+
+    entry = oead.byml.Hash()
+    entry["DataName"] = flag_name
+    entry["DeleteRev"] = oead.S32(-1)
+    entry["HashValue"] = oead.S32(flag_hash)
+    entry["InitValue"] = oead.S32(0)
+    entry["IsEventAssociated"] = False
+    entry["IsOneTrigger"] = True
+    entry["IsProgramReadable"] = True
+    entry["IsProgramWritable"] = True
+    entry["IsSave"] = True
+    entry["MaxValue"] = True
+    entry["MinValue"] = False
+    entry["ResetType"] = oead.S32(0)
+
+    old_flags: set = util.search_bgdict_part(flag_hash, "bool_data")
+
+    if len(old_flags) > 0:
+        for old in old_flags:
+            util.mod_flag_bgdict(entry, old, "bool_data")
+    else:
+        util.new_flag_bgdict(entry, "bool_data")
+
+    return flag_hash
+
+
+def isget_svdata_flag(actor_name: str) -> int:
+    flag_name: str = f"IsGet_{actor_name}"
+    flag_hash: int = ctypes.c_int32(zlib.crc32(flag_name.encode())).value
+
+    entry = oead.byml.Hash()
+    entry["DataName"] = flag_name
+    entry["HashValue"] = oead.S32(flag_hash)
+
+    old_flags: set = util.search_svdict_part(flag_hash, "game_data.sav")
+
+    if len(old_flags) > 0:
+        for old in old_flags:
+            util.mod_flag_svdict(entry, old, "game_data.sav")
+    else:
+        util.new_flag_svdict(entry, "game_data.sav")
+
+    return flag_hash
+
+
 def generate_item_flags(moddir: Path) -> None:
     util.prep_entry_dicts_for_run("bool_data")
 
